@@ -25,23 +25,19 @@ class XNode(Node):
         return max(self.left.height, self.right.height) + 1
 
     def locate(self, point: Point) -> Location:
-        if point < self.point:
-            return self.left.locate(point)
-        elif self.point < point:
-            return self.right.locate(point)
-        else:
-            return Location.BOUNDARY
+        return (self.left.locate(point)
+                if point < self.point
+                else (self.right.locate(point)
+                      if self.point < point
+                      else Location.BOUNDARY))
 
     def search_edge(self, edge: Edge) -> Trapezoid:
-        if self.point <= edge.left:
-            return self.right.search_edge(edge)
-        else:
-            return self.left.search_edge(edge)
+        return (self.right
+                if self.point <= edge.left
+                else self.left).search_edge(edge)
 
     def _replace_child(self, current: Node, replacement: Node) -> None:
         if self.left is current:
             self.left = replacement
         else:
             self.right = replacement
-        current._remove_parent(self)
-        replacement._add_parent(self)
